@@ -1,14 +1,24 @@
 
 pal_pal <- function(palette, direction, dynamic) {
 
+  palette <- try(palette, silent = TRUE)
+  if (inherits(palette, "try-error")) {
+    palette <- attr(palette, "condition")$message
+    palette <- sub("^.*?\"", "", palette)
+    palette <- sub("\".*$", "", palette)
+  }
+
   if (dynamic) {
     function(n) {
-      paletteer_dynamic(palette = {{palette}}, n = n,
-                        direction = direction)
+      paletteer_dynamic(
+        palette = palette,
+        n = n,
+        direction = direction
+      )
     }
   } else {
     function(n) {
-      paletteer_d(palette = {{palette}}, direction = direction)
+      paletteer_d(palette = palette, direction = direction)
     }
   }
 }
@@ -31,20 +41,16 @@ pal_pal <- function(palette, direction, dynamic) {
 #'
 #' @examples
 #'
-#' if (require('ggplot2')) {
-#'
+#' if (require("ggplot2")) {
 #'   ggplot(iris, aes(x = Sepal.Length, y = Sepal.Width, colour = Species)) +
 #'     geom_point() +
 #'     scale_colour_paletteer_d("nord::frost")
 #' }
-#'
 #' @export
 scale_colour_paletteer_d <- function(palette, direction = 1,
                                      dynamic = FALSE, ...) {
 
-  palette_name <- rlang::quo_name(rlang::enquo(palette))
-
-  ggplot2::discrete_scale("colour", palette_name,
+  ggplot2::discrete_scale("colour", "palette_name",
                  pal_pal(palette = {{palette}},
                          dynamic = dynamic, direction = direction), ...)
 
@@ -61,10 +67,7 @@ scale_color_paletteer_d <- scale_colour_paletteer_d
 scale_fill_paletteer_d <- function(palette, direction = 1,
                                    dynamic = FALSE, ...) {
 
-  palette_name <- rlang::quo_name(rlang::enquo(palette))
-
-  ggplot2::discrete_scale("fill", palette_name,
+  ggplot2::discrete_scale("fill", "palette_name",
                  pal_pal(palette = {{palette}},
                          dynamic = dynamic, direction = direction), ...)
-
 }
