@@ -12,16 +12,19 @@
 #' paletteer_c("scico::berlin", 100)
 #' @export
 paletteer_c <- function(palette, n, direction = 1) {
-
   if (abs(direction) != 1) {
-    stop("direction must be 1 or -1")
+    abort("direction must be 1 or -1")
   }
 
-  if (!(palette %in% c_names)) {
-    stop('Palette not found. Make sure both package and palette ',
-         'name are spelled correct in the format "package::palette"')
+  palette <- try(palette, silent = TRUE)
+  if (inherits(palette, "try-error")) {
+    palette <- attr(palette, "condition")$message
+    palette <- sub("^.*?\"", "", palette)
+    palette <- sub("\".*$", "", palette)
   }
 
+  check_palette(palette, c_names)
+
   palette <- unlist(strsplit(palette, "::"))
 
   gen_fun <- wrapper_c[[palette[1]]]
