@@ -15,31 +15,40 @@
 #' paletteer_d("wesanderson::Royal1", 3)
 #' paletteer_d("Redmonder::dPBIPuOr", 14, type = "continuous")
 #' @export
-paletteer_d <- function (palette, n, direction = 1,
-                         type = c("discrete", "continuous")) {
-
+paletteer_d <- function(palette, n, direction = 1,
+                        type = c("discrete", "continuous")) {
   if (abs(direction) != 1) {
-    stop("direction must be 1 or -1")
+    abort("direction must be 1 or -1")
   }
 
   type <- match.arg(type)
 
+  palette <- try(palette, silent = TRUE)
+  if (inherits(palette, "try-error")) {
+    palette <- attr(palette, "condition")$message
+    palette <- sub("^.*?\"", "", palette)
+    palette <- sub("\".*$", "", palette)
+  }
+
+  check_palette(palette, d_names)
+
   palette <- unlist(strsplit(palette, "::"))
 
   pal <- paletteer::palettes_d[[palette]]
-  if (is.null(pal))
-    stop('Palette not found. Make sure both package and palette ',
-         'name are spelled correct in the format "package::palette"')
+
   if (missing(n)) {
     n <- length(pal)
   }
   if (type == "discrete" && n > length(pal)) {
-    stop(paste("Number of requested colors greater than this palette can offer which is ",
-               length(pal), ".", sep = ""))
+    abort(paste("Number of requested colors greater than this palette can offer which is ",
+      length(pal), ".",
+      sep = ""
+    ))
   }
   out <- switch(type,
-                continuous = (grDevices::colorRampPalette(pal))(n),
-                discrete = pal[1:n])
+    continuous = (grDevices::colorRampPalette(pal))(n),
+    discrete = pal[1:n]
+  )
 
   if (direction == -1) {
     prismatic::color(rev(out))
